import { __decorate, __awaiter } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ɵɵinject, Injector, Component, NgModule } from '@angular/core';
import { KeycloakService } from 'keycloak-angular';
import { HttpClient } from '@angular/common/http';
import { CommonModule } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { MatMenuModule } from '@angular/material/menu';

let EkinasHeaderService = class EkinasHeaderService {
    constructor() {
    }
};
EkinasHeaderService.ɵprov = ɵɵdefineInjectable({ factory: function EkinasHeaderService_Factory() { return new EkinasHeaderService(); }, token: EkinasHeaderService, providedIn: "root" });
EkinasHeaderService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], EkinasHeaderService);

const backendUrl = 'http://localhost:8080/movies-meta-api';
const bavicUrl = 'http://localhost:8081/ekinas-bavic-api';
const keycloakConfig = {
    url: 'http://ekinas:8080/auth/',
    realm: 'ekinas-int',
    clientId: 'ekinas-client',
};
const environment = {
    keycloakConfig,
    production: false,
    backendUrl,
    bavicUrl,
    ENV_NAME: 'Development',
    VERSION_URL: backendUrl + ':4200/assets/version.json',
    MOVIES_URL: backendUrl + '/information-objects',
    MICROSERVICES_URL: backendUrl + '/microservices-urls',
    OSDS_URL: backendUrl + '/original-storages-data',
    COPYRIGHTS_URL: backendUrl + '/copyrights',
    DIGITAL_COPIES_URL: backendUrl + '/digital-copies',
    TAPES_DIGITALIZATIONS_URL: backendUrl + '/tapes-digitalizations',
    TAPES_INSPECTIONS_URL: backendUrl + '/tapes-inspections',
};
/*
 * For easier debugging in development mode, you can import the following file
 * to ignore zone related error stack frames such as `zone.run`, `zoneDelegate.invokeTask`.
 *
 * This import should be commented out in production mode because it will have a negative impact
 * on performance if an error is thrown.
 */
// import 'zone.js/dist/zone-error';  // Included with Angular CLI.

class AuthenticatingController {
    constructor(injector) {
        this.injector = injector;
        this.authData = this.injector.get(KeycloakService);
    }
    hasRole(role) {
        return this.authData.isUserInRole(role);
    }
    hasAnyRole(roles) {
        return roles.filter((r) => this.authData.isUserInRole(r)).length > 0;
    }
    getGrantedRoles() {
        return this.authData.getUserRoles();
    }
    hasRoleInClient(clientId) {
        const kra = this.authData.getKeycloakInstance().resourceAccess;
        return kra && kra[clientId] && kra[clientId].roles.length > 0;
    }
    getUserInfo() {
        return this.authData.loadUserProfile();
    }
    isLoggedIn() {
        return this.authData.isLoggedIn();
    }
    redirectToAccountEditUrl(returnUrl) {
        if (!returnUrl) {
            returnUrl = window.location.href;
        }
        window.open(environment.keycloakConfig.url
            + 'realms/' + environment.keycloakConfig.realm
            + '/account/?referrer_uri='
            + returnUrl, '_account');
    }
}

class MicroservicesUrls {
    constructor(metadataUrl = '', administrationUrl = '', eservicesUrl = '', classifierUrl = '') {
        this.metadataUrl = metadataUrl;
        this.administrationUrl = administrationUrl;
        this.eservicesUrl = eservicesUrl;
        this.classifierUrl = classifierUrl;
    }
}

let MicroservicesUrlsService = class MicroservicesUrlsService {
    constructor(http) {
        this.http = http;
        this.microservicesUrlsBackendUrl = environment.MICROSERVICES_URL;
    }
    load() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.http.get(this.microservicesUrlsBackendUrl + '/all', {}).toPromise().then(c => {
                this.microservicesUrls = c;
            });
        });
    }
    getUrl() {
        return this.microservicesUrls;
    }
};
MicroservicesUrlsService.ctorParameters = () => [
    { type: HttpClient }
];
MicroservicesUrlsService.ɵprov = ɵɵdefineInjectable({ factory: function MicroservicesUrlsService_Factory() { return new MicroservicesUrlsService(ɵɵinject(HttpClient)); }, token: MicroservicesUrlsService, providedIn: "root" });
MicroservicesUrlsService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], MicroservicesUrlsService);

let EkinasHeaderComponent = class EkinasHeaderComponent extends AuthenticatingController {
    constructor(microservicesUrlsService, injector) {
        super(injector);
        this.microservicesUrlsService = microservicesUrlsService;
        this.microservicesUrls = new MicroservicesUrls();
        this.firstname = '';
        this.lastname = '';
        this.microservicesUrls = microservicesUrlsService.getUrl();
        this.getUserInfo().then((keycloakProfile) => {
            this.firstname = keycloakProfile.firstName;
            this.lastname = keycloakProfile.lastName;
        });
    }
    logout() {
        this.authData.logout().then(() => {
        });
    }
};
EkinasHeaderComponent.ctorParameters = () => [
    { type: MicroservicesUrlsService },
    { type: Injector }
];
EkinasHeaderComponent = __decorate([
    Component({
        selector: 'lib-ekinas-header',
        template: "<div [ngClass]=\"'main-menu-div'\">\r\n  <div [ngClass]=\"'red-circle'\"></div>\r\n  <div [ngClass]=\"'header-main-title'\">E-KINAS</div>\r\n  <div [ngClass]=\"'header-sub-title'\">Vidin\u0117 sistema</div>\r\n  <div [ngClass]=\"'header-links-div'\">\r\n    <a href=\"{{microservicesUrls.metadataUrl + '/main/movies'}} \">Film\u0173 s\u0105ra\u0161as</a>\r\n    <a href=\"{{microservicesUrls.administrationUrl + '/upload'}} \">Duomen\u0173 \u012Fvedimas</a>\r\n    <a href=\"{{microservicesUrls.administrationUrl + '/tasks'}} \">U\u017Eduotys</a>\r\n    <a href=\"{{microservicesUrls.eservicesUrl + '/list'}} \">El. paslaug\u0173 s\u0105ra\u0161as</a>\r\n    <div>\r\n      <div [ngClass]=\"['user-name', 'user-name-upper']\">{{firstname}}</div>\r\n      <div [ngClass]=\"['user-name', 'user-name-lower']\">{{lastname}}</div>\r\n    </div>\r\n    <div [ngClass]=\"'white-circle-user'\" [matMenuTriggerFor]=\"menu\">\r\n      <mat-icon svgIcon=\"person-black-24dp\"></mat-icon>\r\n      <mat-menu #menu=\"matMenu\" xPosition=\"before\">\r\n        <button mat-menu-item disabled>\r\n          <span [ngClass]=\"'user-menu-span-name'\">{{firstname}} {{lastname}}</span>\r\n        </button>\r\n        <button mat-menu-item [ngClass]=\"'user-menu'\" (click)=\"logout()\">\r\n          <mat-icon [ngClass]=\"'user-menu-icon'\">logout</mat-icon>\r\n          <span [ngClass]=\"'user-menu-span'\">ATSIJUNGTI</span>\r\n        </button>\r\n      </mat-menu>\r\n    </div>\r\n    <div [ngClass]=\"'white-circle-messages'\">\r\n      <mat-icon matBadgeSize=\"small\" matBadgePosition=\"above after\" matBadge=\"15\" matBadgeColor=\"warn\"\r\n                svgIcon=\"email-black-18dp\"></mat-icon>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
        styles: [""]
    })
], EkinasHeaderComponent);

let EkinasHeaderModule = class EkinasHeaderModule {
};
EkinasHeaderModule = __decorate([
    NgModule({
        declarations: [EkinasHeaderComponent],
        imports: [CommonModule, MatIconModule, MatMenuModule],
        exports: [EkinasHeaderComponent]
    })
], EkinasHeaderModule);

/*
 * Public API Surface of ekinas-header
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EkinasHeaderComponent, EkinasHeaderModule, EkinasHeaderService, AuthenticatingController as ɵa, MicroservicesUrlsService as ɵb };
//# sourceMappingURL=ekinas-header.js.map
